body {
    margin: 0;
    padding: 0;

    font-family: sans-serif;
    color: #fff;
}

h1 {
    font-size: 3em;
    color: #444;
}

p {
    line-height: 1.5em;
    color: #888;
}

a {
    color: #fff;
}
a:hover,
a:active {
    text-decoration: underline;
}

em {
    display: inline-block;
    padding: 0 5px;
    background: #f4f4f4;
    border-radius: 5px;
    font-style: normal;
    font-weight: bold;
    color: #444;
}

form {
    color: #444;
}
label {
    display: block;
    font-weight: bold;
}

input[type=text],
input[type=password] {
    margin-bottom: 1em;
    padding: 0.4em;
    max-width: 330px;
    width: 100%;
    border: 1px solid #c4c4c4;
    border-radius: 5px;
    outline: 0;
    font-size: 1.2em;
}
input[type=text]:focus,
input[type=password]:focus,
input[type=text]:active,
input[type=password]:active {
    border-color: #41AFCA;
}

input[type=submit] {
    font-size: 1em;
}

.container {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background: #424A55;
    background-image: -webkit-linear-gradient(270deg, rgba(48,52,62,0) 24%, #30353e 100%);
    background-image: linear-gradient(-180deg, rgba(48,52,62,0) 24%, #30353e 100%);
}

.section {
    padding: 3em;
}
.white.section {
    background: #fff;
    border-bottom: 4px solid #41AFCA;
}

.white.section a {
    text-decoration: none;
    color: #41AFCA;
}
.white.section a:hover,
.white.section a:active {
    text-decoration: underline;
}

.container > .section {
    background: #424A55;
}

.block {
    margin: 0 auto;
    max-width: 900px;
    width: 100%;
}
