%% Generated by the Erlang ASN.1 compiler. Version: 5.3.1
%% Purpose: Erlang record definitions for each named and unnamed
%% SEQUENCE and SET, and macro definitions for each value
%% definition in module XmppAddr.

-ifndef(_XMPPADDR_HRL_).
-define(_XMPPADDR_HRL_, true).

-define('id-on-xmppAddr', {1,3,6,1,5,5,7,8,5}).
-endif. %% _XMPPADDR_HRL_
